#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_STRUCT_OSOCKADDR
#undef HAVE_LIBSM
#undef HAVE_LIBINTL_H
#undef HAVE_PROGRAM_INVOCATION_NAME
#undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
#undef HAVE_SIGACTION_H
#undef HAVE_SIGSET_H
#undef HAVE_GTKHTML
#undef HAVE_GNOME_PRINT
#undef BALSA_MAJOR
#undef BALSA_PATCHLEVEL
#undef BALSA_REVISION
#undef BALSA_VERSION
#undef BALSA_SHOW_ALL
#undef PACKAGE
#undef VERSION

#undef MUTT_MAJOR
#undef MUTT_PATCHLEVEL
#undef MUTT_REVISION
#undef MUTT_VERSION
#undef SENDMAIL
#undef USE_POP
#undef USE_IMAP

/* Shall we multithread? */
#undef BALSA_USE_THREADS

/* LDAP support? */
#undef ENABLE_LDAP

#undef BALSA_STD_PREFIX
#undef BALSA_DATA_PREFIX
#undef GNOME_STD_PREFIX
#undef GNOME_LIB_PREFIX
#undef GNOME_DATA_PREFIX

/* The prefixes to look for balsa data, at least most likely */
#undef BALSA_COMMON_PREFIXES
